@@ -1,7 +1,7 @@
 package Guacamole;
 our $AUTHORITY = 'cpan:XSAWYERX';
 # ABSTRACT: A parser toolkit for Standard Perl
-$Guacamole::VERSION = '0.001';
+$Guacamole::VERSION = '0.002';
 use strict;
 use warnings;
 use Marpa::R2;
@@ -2000,7 +2000,8 @@ sub build_struct {
     while ( my $valueref = shift @values ) {
         if ( ! ref ${$valueref} ) {
             ${$valueref} = {
-                'type'  => ':bare',
+                'name'  => '',
+                'type'  => 'lexeme',
                 'value' => ${$valueref},
             };
 
@@ -2015,7 +2016,7 @@ sub build_struct {
         my ( $line, $column ) = $rec->line_column($start_pos);
         ${$valueref} = {
             'name'      => $name,
-            'type'      => 'lexeme',
+            'type'      => 'rule',
             'start_pos' => $start_pos,
             'length'    => $length,
             'children'  => \@children,
@@ -2084,7 +2085,7 @@ Guacamole - A parser toolkit for Standard Perl
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
